@@ -46,23 +46,23 @@ import (
 	wm "github.com/linuxdeepin/go-dbus-factory/com.deepin.wm"
 	login1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.login1"
 	timedate "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.timedate1"
+	gio "github.com/linuxdeepin/go-gir/gio-2.0"
+	"github.com/linuxdeepin/go-lib/dbusutil"
+	"github.com/linuxdeepin/go-lib/dbusutil/gsprop"
+	"github.com/linuxdeepin/go-lib/dbusutil/proxy"
+	"github.com/linuxdeepin/go-lib/log"
+	"github.com/linuxdeepin/go-lib/strv"
+	dutils "github.com/linuxdeepin/go-lib/utils"
+	"github.com/linuxdeepin/go-lib/xdg/basedir"
 	x "github.com/linuxdeepin/go-x11-client"
 	"github.com/linuxdeepin/go-x11-client/ext/randr"
-	"pkg.deepin.io/dde/api/theme_thumb"
-	"pkg.deepin.io/dde/daemon/appearance/background"
-	"pkg.deepin.io/dde/daemon/appearance/fonts"
-	"pkg.deepin.io/dde/daemon/appearance/subthemes"
-	"pkg.deepin.io/dde/daemon/common/dsync"
-	ddbus "pkg.deepin.io/dde/daemon/dbus"
-	"pkg.deepin.io/dde/daemon/session/common"
-	gio "pkg.deepin.io/gir/gio-2.0"
-	"pkg.deepin.io/lib/dbusutil"
-	"pkg.deepin.io/lib/dbusutil/gsprop"
-	"pkg.deepin.io/lib/dbusutil/proxy"
-	"pkg.deepin.io/lib/log"
-	"pkg.deepin.io/lib/strv"
-	dutils "pkg.deepin.io/lib/utils"
-	"pkg.deepin.io/lib/xdg/basedir"
+	"github.com/linuxdeepin/dde-api/theme_thumb"
+	"github.com/linuxdeepin/dde-daemon/appearance/background"
+	"github.com/linuxdeepin/dde-daemon/appearance/fonts"
+	"github.com/linuxdeepin/dde-daemon/appearance/subthemes"
+	"github.com/linuxdeepin/dde-daemon/common/dsync"
+	ddbus "github.com/linuxdeepin/dde-daemon/dbus"
+	"github.com/linuxdeepin/dde-daemon/session/common"
 )
 
 //go:generate dbusutil-gen em -type Manager
@@ -149,15 +149,15 @@ type Manager struct {
 	monitorMap     map[string]string
 	coordinateMap  map[string]*coordinate
 
-	userObj             *accounts.User
-	imageBlur           *accounts.ImageBlur
-	timeDate            *timedate.Timedate
-	sessionTimeDate     *sessiontimedate.Timedate
-	imageEffect         *imageeffect.ImageEffect
-	xSettings           *sessionmanager.XSettings
-	login1Manager       *login1.Manager
+	userObj             accounts.User
+	imageBlur           accounts.ImageBlur
+	timeDate            timedate.Timedate
+	sessionTimeDate     sessiontimedate.Timedate
+	imageEffect         imageeffect.ImageEffect
+	xSettings           sessionmanager.XSettings
+	login1Manager       login1.Manager
 	themeAutoTimer      *time.Timer
-	display             *display.Display
+	display             display.Display
 	latitude            float64
 	longitude           float64
 	locationValid       bool
@@ -179,7 +179,7 @@ type Manager struct {
 	desktopBgs      []string
 	greeterBg       string
 	curMonitorSpace string
-	wm              *wm.Wm
+	wm              wm.Wm
 
 	//nolint
 	signals *struct {
@@ -643,7 +643,7 @@ func (m *Manager) handleWmWorkspaceCountChanged(count int32) {
 
 		numAdded := int(count) - len(bgs)
 		for i := 0; i < numAdded; i++ {
-			idx := rand.Intn(len(allBgs))
+			idx := rand.Intn(len(allBgs)) // #nosec G404
 			// Id is file url
 			bgs = append(bgs, allBgs[idx].Id)
 		}
@@ -1501,10 +1501,10 @@ func (m *Manager) updateNewVersionData() error {
 	primaryMonitor := reverseMonitorMap["Primary"]
 	slideshowConfig := make(mapMonitorWorkspaceWSPolicy)
 	slideShow := m.WallpaperSlideShow.Get()
+	workspaceCount, _ := m.wm.WorkspaceCount(0)
 	_, err := doUnmarshalWallpaperSlideshow(slideShow)
 	if err != nil {
 		// slideShow的内容无法解析为map[string]string数据表示低版本壁纸，进行数据格式转换
-		workspaceCount, _ := m.wm.WorkspaceCount(0)
 		for i := 1; i <= int(workspaceCount); i++ {
 			key := genMonitorKeyString(primaryMonitor, i)
 			slideshowConfig[key] = slideShow
@@ -1515,21 +1515,21 @@ func (m *Manager) updateNewVersionData() error {
 		}
 	}
 
+	// V20对应SP3, SP2阶段gsettings background-uris中部分数据丢失，SP2升到SP3通过窗管接口获取壁纸
 	monitorWorkspaceWallpaperURIs := make(mapMonitorWorkspaceWallpaperURIs)
-	backgroundURIs := m.getBackgroundURIs()
-	for i, uri := range backgroundURIs {
-		err := m.wm.SetWorkspaceBackgroundForMonitor(0, int32(i+1), primaryMonitor, uri)
-		if err != nil {
-			return fmt.Errorf("failed to set background:%v to workspace%v : %v", uri, i+1, err)
+	for monitorName, convertMonitorName := range m.monitorMap {
+		for i := int32(0); i < workspaceCount; i++ {
+			uri, err := m.wm.GetWorkspaceBackgroundForMonitor(0, i+1, monitorName)
+			if err != nil {
+				logger.Warningf("failed to get monitor:%v workspace:%v background:%v", monitorName, i+1, err)
+				continue
+			}
+
+			key := genMonitorKeyString(convertMonitorName, i+1)
+			monitorWorkspaceWallpaperURIs[key] = uri
 		}
-		key := genMonitorKeyString("Primary", i+1)
-		monitorWorkspaceWallpaperURIs[key] = uri
 	}
-	err = m.setPropertyWallpaperURIs(monitorWorkspaceWallpaperURIs)
-	if err != nil {
-		return err
-	}
-	return nil
+	return m.setPropertyWallpaperURIs(monitorWorkspaceWallpaperURIs)
 }
 
 func genMonitorKeyString(monitor string, idx interface{}) string {
