@@ -8,7 +8,8 @@ import (
 
 const (
 	PortTypeBluetooth    int = iota // 蓝牙音频
-	PortTypeHeadset                 // USB和3.5mm 耳麦
+	PortTypeHeadset                 // 3.5mm 耳麦
+	PortTypeUsb                     // USB
 	PortTypeBuiltin                 // 内置扬声器和话筒
 	PortTypeHdmi                    // HDMI
 	PortTypeLineIO                  // 线缆输入输出
@@ -56,10 +57,15 @@ func DetectPortType(card *pulse.Card, port *pulse.CardPortInfo) int {
 
 	if hasKeyword(stringList, "rear-mic") ||
 		hasKeyword(stringList, "front-mic") ||
-		hasKeyword(stringList, "headphone") {
+		hasKeyword(stringList, "headphone") ||
+		hasKeyword(stringList, "headset") {
 		return PortTypeHeadset
 	}
 
+	if hasKeyword(stringList, "usb") {
+		return PortTypeUsb
+	}
+
 	if hasKeyword(stringList, "hdmi") {
 		return PortTypeHdmi
 	}
@@ -153,7 +159,7 @@ func (pp *PriorityPolicy) sortPorts() {
 			type2 := port2.PortType
 
 			// type1优先级比type2低，交换
-			if pp.GetPreferType(type1, type2) == type2 {
+			if type1 != type2 && pp.GetPreferType(type1, type2) == type2 {
 				pp.Ports[j], pp.Ports[j+1] = pp.Ports[j+1], pp.Ports[j]
 				logger.Debugf("swap <%s:%s> and <%s:%s>",
 					pp.Ports[j].CardName, pp.Ports[j].PortName,
