@@ -3,7 +3,7 @@ package main
 import (
 	"github.com/godbus/dbus"
 	login1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.login1"
-	"pkg.deepin.io/lib/dbusutil"
+	"github.com/linuxdeepin/go-lib/dbusutil"
 )
 
 func (d *Daemon) forwardPrepareForSleepSignal(service *dbusutil.Service) error {
