@@ -1,8 +1,8 @@
 package image_effect
 
 import (
-	"pkg.deepin.io/dde/daemon/loader"
-	"pkg.deepin.io/lib/log"
+	"github.com/linuxdeepin/go-lib/log"
+	"github.com/linuxdeepin/dde-daemon/loader"
 )
 
 func init() {
@@ -10,15 +10,15 @@ func init() {
 }
 
 type Module struct {
-	ie *ImageEffect
 	*loader.ModuleBase
+	ie *ImageEffect
 }
 
-func (m Module) GetDependencies() []string {
+func (m *Module) GetDependencies() []string {
 	return nil
 }
 
-func (m Module) Start() error {
+func (m *Module) Start() error {
 	if m.ie != nil {
 		return nil
 	}
@@ -32,7 +32,7 @@ func (m Module) Start() error {
 	return nil
 }
 
-func (m Module) Stop() error {
+func (m *Module) Stop() error {
 	// TODO
 	return nil
 }
