@@ -20,11 +20,8 @@
 package inputdevices
 
 import (
-	"os"
-
-	"github.com/godbus/dbus"
-	"github.com/linuxdeepin/go-lib/gsettings"
 	"github.com/linuxdeepin/dde-api/dxinput"
+	"github.com/linuxdeepin/go-lib/gsettings"
 )
 
 func (m *Manager) handleGSettings() {
@@ -38,31 +35,7 @@ func (kbd *Keyboard) handleGSettings() {
 		switch key {
 		case kbdKeyRepeatEnable, kbdKeyRepeatDelay,
 			kbdKeyRepeatInterval:
-			if len(os.Getenv("WAYLAND_DISPLAY")) != 0 {
-				if kbd.shouldUseDDEKwin() {
-					sessionBus, err := dbus.SessionBus()
-					if err != nil {
-						logger.Warning(err)
-						return
-					}
-					var (
-						delay    = kbd.RepeatDelay.Get()
-						interval = kbd.RepeatInterval.Get()
-					)
-					//+ 前端interval范围是20-100,kwin中值是相反的,kwin无法得知范围,故后端处理下
-					interval = 120 - interval
-					obj := sessionBus.Object("org.kde.KWin", "/KWin")
-					err = obj.Call("org.kde.KWin.setRepeatRateAndDelay", 0, int32(interval), int32(delay)).Err
-					if err != nil {
-						logger.Warning(err)
-						return
-					}
-				} else {
-					kbd.applyRepeat()
-				}
-			} else {
-				kbd.applyRepeat()
-			}
+			kbd.applyRepeat()
 		case kbdKeyCursorBlink:
 			kbd.applyCursorBlink()
 		case kbdKeyLayoutOptions:
