@@ -256,27 +256,27 @@ func (m *Manager) init() {
 		} else {
 			m.shortcutManager.AddSpecial()
 			m.shortcutManager.AddSystem(m.gsSystem, m.gsSystemPlatform, m.gsSystemEnable, m.wm)
-			m.shortcutManager.AddMedia(m.gsMediaKey)
+			m.shortcutManager.AddMedia(m.gsMediaKey, m.wm)
 			m.gsGnomeWM = gio.NewSettings(gsSchemaGnomeWM)
-			m.shortcutManager.AddWM(m.gsGnomeWM)
+			m.shortcutManager.AddWM(m.gsGnomeWM, m.wm)
 		}
 	} else {
 		m.shortcutManager.AddSystem(m.gsSystem, m.gsSystemPlatform, m.gsSystemEnable, m.wm)
-		m.shortcutManager.AddMedia(m.gsMediaKey)
+		m.shortcutManager.AddMedia(m.gsMediaKey, m.wm)
 		if shouldUseDDEKwin() {
 			logger.Debug("Use DDE KWin")
 			m.shortcutManager.AddKWin(m.wm)
 		} else {
 			logger.Debug("Use gnome WM")
 			m.gsGnomeWM = gio.NewSettings(gsSchemaGnomeWM)
-			m.shortcutManager.AddWM(m.gsGnomeWM)
+			m.shortcutManager.AddWM(m.gsGnomeWM, m.wm)
 		}
 	}
 
 	// init custom shortcuts
 	customConfigFilePath := filepath.Join(basedir.GetUserConfigDir(), customConfigFile)
 	m.customShortcutManager = shortcuts.NewCustomShortcutManager(customConfigFilePath)
-	m.shortcutManager.AddCustom(m.customShortcutManager)
+	m.shortcutManager.AddCustom(m.customShortcutManager, m.wm)
 
 	// init controllers
 	m.backlightHelper = backlight.NewBacklight(sysBus)
@@ -351,11 +351,11 @@ var kwinSysActionCmdMap = map[string]string{
 	// cmd
 	"Calculator":         "calculator",          // XF86Calculator
 	"Search":             "search",              // XF86Search
-	"NotificationCenter": "notification-center", // Meta M
+	"Notification Center": "notification-center", // Meta M
 
 	"ScreenshotScroll": "screenshot-scroll",
 	"ScreenshotOcr":    "screenshot-ocr",
-	"GlobalSearch":     "global-search",
+	"Global Search":    "global-search",
 }
 
 var waylandMediaIdMap = map[string]string{
@@ -431,18 +431,29 @@ func (m *Manager) listenGlobalAccel(sessionBus *dbus.Conn) error {
 			ok := strings.Compare(string("kwin"), m.shortcutKey)
 			if ok == 0 {
 				logger.Debug("[test global key] get accel sig.Body[1]", sig.Body[1])
-				m.shortcutCmd = shortcuts.GetSystemActionCmd(kwinSysActionCmdMap[m.shortcutKeyCmd])
 				if m.shortcutKeyCmd == "" {
 					//+ 把响应一次的逻辑放到协程外执行，防止协程响应延迟
 					m.handleKeyEventByWayland(waylandMediaIdMap[m.shortcutKeyCmd])
 				} else {
+					m.shortcutCmd = shortcuts.GetSystemActionCmd(kwinSysActionCmdMap[m.shortcutKeyCmd])
+					if m.shortcutCmd == "" {
+						m.shortcutCmd = m.shortcutManager.WaylandCustomShortCutMap[m.shortcutKeyCmd]
+					}
+					logger.Debug("WaylandCustomShortCutMap", m.shortcutCmd)
 					if m.shortcutCmd == "" {
 						m.handleKeyEventByWayland(waylandMediaIdMap[m.shortcutKeyCmd])
 					} else {
-						err := m.execCmd(m.shortcutCmd, true)
-						if err != nil {
-							logger.Warning(err)
-						}
+						if strings.HasSuffix(m.shortcutCmd, ".desktop") {
+							err := m.runDesktopFile(m.shortcutCmd)
+							if err != nil {
+								logger.Warning(err)
+							}
+						} else {
+							err := m.execCmd(m.shortcutCmd, true)
+							if err != nil {
+								logger.Warning(err)
+							}
+						}					
 					}
 				}
 			}
@@ -586,24 +597,16 @@ func (m *Manager) initNumLockState(sysBus *dbus.Conn) {
 			// 保存新状态到 gsettings
 			m.NumLockState.Set(int32(state))
 		}
-		err = setNumLockState(m.conn, m.keySymbols, state)
+
+		err = setNumLockState(m.waylandOutputMgr, m.conn, m.keySymbols, state)
 		if err != nil {
 			logger.Warning("setNumLockState failed:", err)
 		}
 	} else {
-		if _useWayland {
-			if saveStateEnabled {
-				err := setNumLockWl(m.waylandOutputMgr, m.conn, nlState)
-				if err != nil {
-					logger.Warning("setNumLockWl failed:", err)
-				}
-			}
-		} else {
-			if saveStateEnabled {
-				err := setNumLockState(m.conn, m.keySymbols, nlState)
-				if err != nil {
-					logger.Warning("setNumLockState failed:", err)
-				}
+		if saveStateEnabled {
+			err := setNumLockState(m.waylandOutputMgr, m.conn, m.keySymbols, nlState)
+			if err != nil {
+				logger.Warning("setNumLockState failed:", err)
 			}
 		}
 	}
@@ -1036,7 +1039,7 @@ func (m *Manager) listenSystemEnableChanged() {
 		}
 
 		if m.shortcutManager.CheckSystem(m.gsSystemPlatform, m.gsSystemEnable, key) {
-			m.shortcutManager.AddSystemById(m.gsSystem, key)
+			m.shortcutManager.AddSystemById(m.gsSystem, m.wm, key)
 		} else {
 			m.shortcutManager.DelSystemById(key)
 		}
@@ -1050,7 +1053,7 @@ func (m *Manager) listenSystemPlatformChanged() {
 		}
 
 		if m.shortcutManager.CheckSystem(m.gsSystemPlatform, m.gsSystemEnable, key) {
-			m.shortcutManager.AddSystemById(m.gsSystem, key)
+			m.shortcutManager.AddSystemById(m.gsSystem, m.wm, key)
 		} else {
 			m.shortcutManager.DelSystemById(key)
 		}
