@@ -49,7 +49,9 @@ func getSystemIdNameMap() map[string]string {
 		"speech-to-text":         gettext.Tr("Speech to Text"),
 		"clipboard":              gettext.Tr("Clipboard"),
 		"translation":            gettext.Tr("Translation"),
-		"global-search":          gettext.Tr("Grand search"),
+		"global-search":          gettext.Tr("Grand Search"),
+		"notification-center":    gettext.Tr("Notification Center"),
+		"switch-next-kbd-layout": gettext.Tr("Swicth next keyboard layout"),
 	}
 	return idNameMap
 }
