@@ -13,14 +13,16 @@ import (
 	"sync"
 	"time"
 
-	dbus "github.com/godbus/dbus"
+	"github.com/godbus/dbus"
+	"github.com/linuxdeepin/dde-daemon/network/nm"
+	ofdbus "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.dbus"
 	secrets "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.secrets"
-	"pkg.deepin.io/dde/daemon/network/nm"
-	"pkg.deepin.io/lib/dbusutil"
-	"pkg.deepin.io/lib/strv"
+	"github.com/linuxdeepin/go-lib/dbusutil"
+	"github.com/linuxdeepin/go-lib/strv"
 )
 
 const (
+	// #nosec
 	nmSecretDialogBin              = "/usr/lib/deepin-daemon/dnetwork-secret-dialog"
 	getSecretsFlagAllowInteraction = 0x1
 	getSecretsFlagRequestNew       = 0x2
@@ -50,10 +52,12 @@ type saveSecretsTask struct {
 }
 
 type SecretAgent struct {
-	secretService       *secrets.Service
+	sessionSigLoop      *dbusutil.SignalLoop
+	secretService       secrets.Service
 	secretSessionPath   dbus.ObjectPath
-	defaultCollection   *secrets.Collection
+	defaultCollection   secrets.Collection
 	defaultCollectionMu sync.Mutex
+	tryUnlockColMu      sync.Mutex
 
 	saveSecretsTasks   map[saveSecretsTaskKey]saveSecretsTask
 	saveSecretsTasksMu sync.Mutex
@@ -101,7 +105,20 @@ func (sa *SecretAgent) getSaveSecretsTaskProcess(connPath dbus.ObjectPath,
 	return task.process
 }
 
-func (sa *SecretAgent) getDefaultCollection() (*secrets.Collection, error) {
+// getDefaultCollection 获取默认密钥环，并且尝试解锁它。
+func (sa *SecretAgent) getDefaultCollection() (secrets.Collection, error) {
+	col, err := sa.getDefaultCollectionAux()
+	if err != nil {
+		return nil, err
+	}
+	err = sa.tryUnlockCollection(col)
+	if err != nil {
+		return nil, err
+	}
+	return col, nil
+}
+
+func (sa *SecretAgent) getDefaultCollectionAux() (secrets.Collection, error) {
 	sa.defaultCollectionMu.Lock()
 	defer sa.defaultCollectionMu.Unlock()
 
@@ -130,19 +147,27 @@ func (sa *SecretAgent) getDefaultCollection() (*secrets.Collection, error) {
 	return collectionObj, err
 }
 
-func newSecretAgent(secServiceObj *secrets.Service, manager *Manager) (*SecretAgent, error) {
+func newSecretAgent(secServiceObj secrets.Service, manager *Manager) (*SecretAgent, error) {
 	_, sessionPath, err := secServiceObj.OpenSession(0, "plain", dbus.MakeVariant(""))
 	if err != nil {
 		return nil, err
 	}
 
 	sa := &SecretAgent{}
+	sa.sessionSigLoop = manager.sessionSigLoop
 	sa.secretSessionPath = sessionPath
 	sa.secretService = secServiceObj
 	sa.saveSecretsTasks = make(map[saveSecretsTaskKey]saveSecretsTask)
 	sa.m = manager
 	sa.needSleep = true
 	logger.Debug("session path:", sessionPath)
+
+	// 尽早解锁密钥环
+	_, err = sa.getDefaultCollection()
+	if err != nil {
+		logger.Warning(err)
+	}
+
 	return sa, nil
 }
 
@@ -178,6 +203,104 @@ func (sa *SecretAgent) deleteAll(uuid string) error {
 	return nil
 }
 
+// tryUnlockCollection 尝试解锁密钥环，如果返回错误则解锁失败。
+func (sa *SecretAgent) tryUnlockCollection(collection secrets.Collection) error {
+	// 保证同时只有一个解锁对话框
+	sa.tryUnlockColMu.Lock()
+	defer sa.tryUnlockColMu.Unlock()
+
+	locked, err := collection.Locked().Get(0)
+	if err != nil {
+		return err
+	}
+	if !locked {
+		// 未上锁，直接返回
+		return nil
+	}
+
+	collectionPath := collection.Path_()
+
+	unlocked, promptPath, err := sa.secretService.Unlock(0, []dbus.ObjectPath{collectionPath})
+	if err != nil {
+		return err
+	}
+	logger.Debugf("call Unlock unlocked: %v, promptPath: %v", unlocked, promptPath)
+	for _, objPath := range unlocked {
+		if objPath == collectionPath {
+			// 大概已经无密码自动解锁了
+			return nil
+		}
+	}
+
+	if promptPath == "/" {
+		return errors.New("invalid prompt path")
+	}
+
+	sessionBus := sa.sessionSigLoop.Conn()
+
+	promptObj, err := secrets.NewPrompt(sessionBus, promptPath)
+	if err != nil {
+		return err
+	}
+	promptObj.InitSignalExt(sa.sessionSigLoop, true)
+	ch := make(chan error)
+
+	// 防止 org.freedesktop.secrets 服务异常退出，造成 promptObj 不能收到信号，让代码卡住。
+	dbusDaemon := ofdbus.NewDBus(sessionBus)
+	dbusDaemon.InitSignalExt(sa.sessionSigLoop, true)
+	_, err = dbusDaemon.ConnectNameOwnerChanged(func(name string, oldOwner string, newOwner string) {
+		if name == sa.secretService.ServiceName_() && oldOwner != "" && newOwner == "" {
+			ch <- errors.New(sa.secretService.ServiceName_() + " name lost")
+		}
+	})
+	if err != nil {
+		return err
+	}
+	defer func() {
+		dbusDaemon.RemoveAllHandlers()
+	}()
+
+	// 监听解锁完成信号
+	_, err = promptObj.ConnectCompleted(func(dismissed bool, result dbus.Variant) {
+		// 用户取消解锁
+		if dismissed {
+			ch <- errors.New("prompt dismissed by user")
+			return
+		}
+
+		paths, ok := result.Value().([]dbus.ObjectPath)
+		if !ok {
+			ch <- errors.New("type of result.Value() is not []dbus.ObjectPath")
+			return
+		}
+		for _, objPath := range paths {
+			if objPath == collectionPath {
+				// 正常解锁完成
+				ch <- nil
+				return
+			}
+		}
+		// 这里的情况不太可能发生
+		ch <- errors.New("not found collection path in paths")
+	})
+	if err != nil {
+		return err
+	}
+	defer func() {
+		promptObj.RemoveAllHandlers()
+	}()
+
+	// 调用 Prompt 方法之后就会弹出密钥环解锁对话框
+	err = promptObj.Prompt(0, "")
+	if err != nil {
+		return err
+	}
+
+	// 目前设计成无超时的
+	err = <-ch
+	return err
+}
+
 func (sa *SecretAgent) getAll(uuid, settingName string) (map[string]string, error) {
 	if sa.needSleep {
 		time.Sleep(2 * time.Second)
@@ -282,6 +405,7 @@ func (sa *SecretAgent) set(label, uuid, settingName, settingKey, value string) e
 	if err != nil {
 		return err
 	}
+
 	_, _, err = defaultCollection.CreateItem(0, properties, itemSecret, true)
 	return err
 }
@@ -291,6 +415,8 @@ func (*SecretAgent) GetInterfaceName() string {
 }
 
 type getSecretsRequest struct {
+	DevPaths    []string `json:"devices"`
+	SpcPath     string   `json:"specific"`
 	ConnId      string   `json:"connId"`
 	ConnType    string   `json:"connType"`
 	ConnUUID    string   `json:"connUUID"`
@@ -298,6 +424,7 @@ type getSecretsRequest struct {
 	SettingName string   `json:"settingName"`
 	Secrets     []string `json:"secrets"`
 	RequestNew  bool     `json:"requestNew"`
+	Flag        int      `json:"secretFlag"`
 }
 
 type getSecretsReply struct {
@@ -315,7 +442,7 @@ func isSecretDialogExist() bool {
 
 func (sa *SecretAgent) askPasswords(connPath dbus.ObjectPath,
 	connectionData map[string]map[string]dbus.Variant,
-	connUUID, settingName string, settingKeys []string, requestNew bool) (map[string]string, error) {
+	connUUID, settingName string, settingKeys []string, requestNew bool, secretFlag uint32) (map[string]string, error) {
 
 	logger.Debugf("askPasswords settingName: %v, settingKeys: %v",
 		settingName, settingKeys)
@@ -325,6 +452,30 @@ func (sa *SecretAgent) askPasswords(connPath dbus.ObjectPath,
 
 	vpnService, _ := getConnectionDataString(connectionData, "vpn", "service")
 
+	// search connection in active connections
+	// if found, record device paths and specific object of this active connection
+	var devPaths []dbus.ObjectPath
+	var specific dbus.ObjectPath
+	sa.m.activeConnectionsLock.Lock()
+	for _, active := range sa.m.activeConnections {
+		if active.conn != connPath {
+			continue
+		}
+		// copy device path slice
+		devPaths = make([]dbus.ObjectPath, len(active.Devices))
+		copy(devPaths, active.Devices)
+		// copy specific obj
+		specific = active.SpecificObject
+		break
+	}
+	sa.m.activeConnectionsLock.Unlock()
+
+	// convert object path slice to string slice
+	var paths []string
+	for _, value := range devPaths {
+		paths = append(paths, string(value))
+	}
+
 	var req getSecretsRequest
 	req.ConnId = connId
 	req.ConnType = connType
@@ -333,6 +484,10 @@ func (sa *SecretAgent) askPasswords(connPath dbus.ObjectPath,
 	req.SettingName = settingName
 	req.Secrets = settingKeys
 	req.RequestNew = requestNew
+	req.SpcPath = string(specific)
+	req.DevPaths = paths
+	req.Flag = int(secretFlag)
+
 	reqJSON, err := json.Marshal(&req)
 	if err != nil {
 		return nil, err
@@ -401,6 +556,10 @@ func getSecretFlagsKeyName(key string) string {
 			return "wep-key-flags"
 		}
 	}
+	// case nm dont hve sae-flags, reuse psk-flags at this time
+	if key == "sae" {
+		return "psk-flags"
+	}
 	return key + "-flags"
 }
 
@@ -415,7 +574,10 @@ func isMustAsk(data connectionData, settingName, secretKey string) bool {
 			if secretKey == "psk" {
 				return true
 			}
-
+		case "sae":
+			if secretKey == "psk" {
+				return true
+			}
 		case "none":
 			if secretKey == "wep-key0" && wepTxKeyIdx == 0 {
 				return true
@@ -485,6 +647,7 @@ func (sa *SecretAgent) getSecrets(connectionData map[string]map[string]dbus.Vari
 	setting := make(map[string]dbus.Variant)
 	secretsData[settingName] = setting
 	var vpnSecretsData map[string]string
+	var secretFlag uint32
 	if settingName == "vpn" {
 		if getSettingVpnServiceType(connectionData) == nmOpenConnectServiceType {
 			vpnSecretsData, ok = <-sa.createPendingKey(connectionData, hints, flags)
@@ -508,7 +671,7 @@ func (sa *SecretAgent) getSecrets(connectionData map[string]map[string]dbus.Vari
 
 			if allowInteraction && len(askItems) > 0 {
 				resultAsk, err := sa.askPasswords(connectionPath, connectionData, connUUID,
-					settingName, askItems, requestNew)
+					settingName, askItems, requestNew, secretFlag)
 				if err != nil {
 					logger.Debug("waring askPasswords error:", err)
 					return nil, err
@@ -540,6 +703,7 @@ func (sa *SecretAgent) getSecrets(connectionData map[string]map[string]dbus.Vari
 		for _, secretKey := range secretKeys {
 			secretFlags, _ := getConnectionDataUint32(connectionData, settingName,
 				getSecretFlagsKeyName(secretKey))
+			secretFlag = secretFlags
 
 			if secretFlags == secretFlagAsk {
 				if allowInteraction && isMustAsk(connectionData, settingName, secretKey) {
@@ -548,7 +712,6 @@ func (sa *SecretAgent) getSecrets(connectionData map[string]map[string]dbus.Vari
 			} else if secretFlags == secretFlagNone {
 				secretStr, _ := getConnectionDataString(connectionData, settingName,
 					secretKey)
-
 				if requestNew {
 					secretStr = ""
 				}
@@ -580,7 +743,7 @@ func (sa *SecretAgent) getSecrets(connectionData map[string]map[string]dbus.Vari
 		}
 		if allowInteraction && len(askItems) > 0 {
 			resultAsk, err := sa.askPasswords(connectionPath, connectionData, connUUID,
-				settingName, askItems, requestNew)
+				settingName, askItems, requestNew, secretFlag)
 			if err != nil {
 				logger.Warning("askPasswords error:", err)
 				return nil, errSecretAgentUserCanceled
