@@ -95,7 +95,9 @@ func (m *Manager) handleWakeup() {
 
 	// Fix wayland sometimes no dpms event after wakeup
 	if m.UseWayland {
-		err := m.helper.ScreenSaver.SimulateUserActivity(0)
+		err := m.service.Conn().Object("com.deepin.daemon.KWayland",
+			"/com/deepin/daemon/KWayland/Output").Call("com.deepin.daemon.KWayland.Idle.simulateUserActivity", 0).Err
+
 		if err != nil {
 			logger.Warning(err)
 		}
@@ -160,8 +162,13 @@ func (m *Manager) handleBatteryDisplayUpdate() {
 		m.setPropBatteryState(status)
 
 		warnLevel = m.getWarnLevel(percentage, timeToEmpty)
-		warnLevelChanged = m.setPropWarnLevel(warnLevel)
-
+		// 当电池电量从1%->0%时，如果之前的warnLevel不为WarnLevelNone（电池的状态正常），此时不去做warnLevel改变处理
+		// 防止某些机器在电量变为0时低电量屏保被取消，进入锁屏界面
+		if m.warnLevelConfig.getWarnLevelConfig().UsePercentageForPolicy && percentage == 0.0 && m.WarnLevel != WarnLevelNone {
+			warnLevelChanged = false
+		} else {
+			warnLevelChanged = m.setPropWarnLevel(warnLevel)
+		}
 	} else {
 		warnLevel = WarnLevelNone
 		warnLevelChanged = m.setPropWarnLevel(WarnLevelNone)
