@@ -601,46 +601,45 @@ func (psp *powerSavePlan) HandleIdleOn() {
 		return
 	}
 
-	if isActive, err := psp.manager.isX11SessionActive(); err != nil {
-		logger.Warning(err)
-		return
-	} else if !isActive {
+	if !psp.manager.isSessionActive() {
 		logger.Info("X11 session is inactive, don't HandleIdleOn")
 		return
 	}
 
-	// check window
-	preventIdle, err := psp.shouldPreventIdle()
-	if err != nil {
-		logger.Warning(err)
-	}
-	if preventIdle {
-		logger.Debug("prevent idle")
-		err := psp.manager.helper.ScreenSaver.SimulateUserActivity(0)
-		if err != nil {
-			logger.Warning(err)
-		}
-		return
-	}
-
 	logger.Info("HandleIdleOn")
 
-	idleTime := psp.metaTasks.min()
-	xConn := psp.manager.helper.xConn
-	xDefaultScreen := xConn.GetDefaultScreen()
-	if xDefaultScreen != nil {
-		xInfo, err := xscreensaver.QueryInfo(xConn, x.Drawable(xDefaultScreen.Root)).Reply(xConn)
-		if err == nil {
-			idleTime = int32(xInfo.MsSinceUserInput / 1000)
-		} else {
+	// check window, only x11 is supported, not apply to wayland
+	if !psp.manager.UseWayland {
+		preventIdle, err := psp.shouldPreventIdle()
+		if err != nil {
 			logger.Warning(err)
 		}
-	} else {
-		logger.Warning("cannot get X11 default screen")
-	}
+		if preventIdle {
+			logger.Debug("prevent idle")
+			err := psp.manager.helper.ScreenSaver.SimulateUserActivity(0)
+			if err != nil {
+				logger.Warning(err)
+			}
+			return
+		}
 
-	logger.Debugf("idle time: %d ms", idleTime)
-	psp.metaTasks.setRealDelay(idleTime)
+		idleTime := psp.metaTasks.min()
+		xConn := psp.manager.helper.xConn
+		xDefaultScreen := xConn.GetDefaultScreen()
+		if xDefaultScreen != nil {
+			xInfo, err := xscreensaver.QueryInfo(xConn, x.Drawable(xDefaultScreen.Root)).Reply(xConn)
+			if err == nil {
+				idleTime = int32(xInfo.MsSinceUserInput / 1000)
+			} else {
+				logger.Warning(err)
+			}
+		} else {
+			logger.Warning("cannot get X11 default screen")
+		}
+
+		logger.Debugf("idle time: %d ms", idleTime)
+		psp.metaTasks.setRealDelay(idleTime)
+	}
 
 	for _, t := range psp.metaTasks {
 		logger.Debugf("do %s after %v", t.name, t.realDelay)
@@ -648,7 +647,7 @@ func (psp *powerSavePlan) HandleIdleOn() {
 		psp.addTaskNoLock(task)
 	}
 
-	_, err = os.Stat("/etc/deepin/no_suspend")
+	_, err := os.Stat("/etc/deepin/no_suspend")
 	if err == nil {
 		if psp.manager.ScreenBlackLock.Get() {
 			//m.setDPMSModeOn()
