@@ -21,6 +21,7 @@ package power_manager
 
 import (
 	"os"
+	"os/exec"
 
 	"github.com/godbus/dbus"
 	login1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.login1"
@@ -31,6 +32,8 @@ import (
 type Manager struct {
 	service  *dbusutil.Service
 	objLogin login1.Manager
+
+	VirtualMachineName string
 }
 
 func newManager(service *dbusutil.Service) (*Manager, error) {
@@ -41,6 +44,14 @@ func newManager(service *dbusutil.Service) (*Manager, error) {
 	if err != nil {
 		return nil, err
 	}
+
+	name, err := detectVirtualMachine()
+	if err != nil {
+		logger.Warning(err)
+	}
+
+	m.setPropVirtualMachineName(name)
+
 	return m, nil
 }
 
@@ -70,6 +81,10 @@ func (m *Manager) CanReboot() (can bool, busErr *dbus.Error) {
 }
 
 func (m *Manager) CanSuspend() (can bool, busErr *dbus.Error) {
+	// 虚拟机屏蔽待机
+	if m.VirtualMachineName != "" {
+		return false, nil
+	}
 	_, err := os.Stat("/sys/power/mem_sleep")
 	if os.IsNotExist(err) {
 		return false, nil
@@ -80,6 +95,32 @@ func (m *Manager) CanSuspend() (can bool, busErr *dbus.Error) {
 }
 
 func (m *Manager) CanHibernate() (can bool, busErr *dbus.Error) {
+	// 虚拟机屏蔽休眠
+	if m.VirtualMachineName != "" {
+		return false, nil
+	}
 	str, _ := m.objLogin.CanHibernate(0)
 	return str == "yes", nil
 }
+
+var autoConfigTargets = []string{
+	"suspend.target",
+	"sleep.target",
+	"suspend-then-hibernate.target",
+	"hibernate.target",
+	"hybrid-sleep.target",
+}
+
+func (m *Manager) maskOnVM(enable bool) {
+	var oper string
+	if enable && m.VirtualMachineName != "" {
+		oper = "mask"
+	} else {
+		oper = "unmask"
+	}
+
+	for _, target := range autoConfigTargets {
+		logger.Debug("auto mask on virt")
+		exec.Command("systemctl", oper, target).Run()
+	}
+}
