@@ -68,13 +68,15 @@ func (d *Daemon) Start() error {
 		return err
 	}
 	m.initXExtensions()
-	go m.handleXEvent()
 
 	sessionType := os.Getenv("XDG_SESSION_TYPE")
 	if strings.Contains(sessionType, "wayland") {
 		go m.listenGlobalCursorPressed()
 		go m.listenGlobalCursorRelease()
 		go m.listenGlobalCursorMove()
+		go m.listenGlobalAxisChanged()
+	} else {
+		go m.handleXEvent()
 	}
 
 	err = service.Export(dbusPath, m)
